%Constants used in the relaxation process to optimize performance
c1=0.3375;
c2=0.41;
        
%Limit of the size of the force to decide that the relaxation process has
%converged
forceLimit=10^(-6);

%Parameters of the function describing the roof
global r_GLOBAL
global s_GLOBAL
r_GLOBAL=1;
s_GLOBAL=1;

%The number of points in each direction of the grid
n=21;

%Initiate the grid
x=zeros(n^2,1);
y=zeros(n^2,1);
for i=1:n
    for j=1:n
        x(j+(i-1)*n)=(i-1)/(n-1);
        y(j+(i-1)*n)=(j-1)/(n-1);
    end
end
z=getRoofHeight(x,y);

%Show the initial grid
figure(1);
tri = delaunay(x,y);    % Creates the triangulation
trimesh(tri,x,y,z);

prevDeltap=zeros(3,(n-2)^2);  % This contains the previous adjustment.
                              % Initiated to the zero matrix at first step.
                              
normError=1;        % Contains the norm of the tangential component of
                    % all the force vectors. Initiated to 1 to make it do at
                    % least one step.
                    
counter=0;          % Counts the number of iterations.

% Run the relaxation process until the force is small enough
while normError>forceLimit 
    counter=counter+1;
    
    fM=forceMatrix(x,y,z);       % The q_{i,j} of the article.
    deltap=c1*fM+c2*prevDeltap;  % The deltap of the article.
    [x,y,z]=updateGrid(deltap,x,y,z);  % Update the grid with deltap

    normError=norm(fM);          % Compute the norm of the tangential components
    prevDeltap=deltap;           % Save the adjustment as the previous one
end

fprintf('Antal iterationer: %d c1=%f c2=%f\n',counter,c1,c2);

%Show the updated grid
figure(2);
tri = delaunay(x,y);
trimesh(tri,x,y,z);

